@@ -10,7 +10,7 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use DynaLoader ();
@@ -1363,7 +1363,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -1726,11 +1726,13 @@ When running Devel::Cover's own test suite, $DEVEL_COVER_DEBUG turns on
 debugging information, $DEVEL_COVER_GOLDEN_VERSION overrides Devel::Cover's
 own idea of which golden results it should test against, and
 $DEVEL_COVER_NO_COVERAGE runs the tests without collecting coverage.
-$DEVEL_COVER_DB_FORMAT may be set to either "JSON" or "Storable" to override
-the default choice of DB format (JSON if available, otherwise Storable).
-$DEVEL_COVER_IO_OPTIONS provides fine-grained control over the DB format.  For
-example, setting it to "pretty" when the format is JSON will store the DB in a
-readable JSON format.
+$DEVEL_COVER_DB_FORMAT may be set to "Sereal", "JSON" or "Storable" to
+override the default choice of DB format (Sereal, then JSON if either are
+available, otherwise Storable).  $DEVEL_COVER_IO_OPTIONS provides fine-grained
+control over the DB format.  For example, setting it to "pretty" when the
+format is JSON will store the DB in a readable JSON format.  $DEVEL_COVER_CPUS
+overrides the automated detection of the number of CPUs to use in parallel
+testing.
 
 =head1 ACKNOWLEDGEMENTS
 
